function [time, T_w, T, T_m]=Oven_Brazing(M, t_sim)
% EXAMPLE 3.2-1(b) Oven Brazing
 
% INPUTS
% M - number of time steps (-)
% t_sim - duration of simulation (s)
 
% OUTPUTS
% time - array with the values of time for each time step (s)
% T_w - array containing values of the wall temperature at each time (K)
% T - array containing values of the surface temperature at each time (K)
% T_m - array containing values of the surface temperature at each time from ODE solver (K)

%Known information
V=10/100000;                        	% volume (m^3)
A_s=35/1000;                         	% surface area (m^2)
e=0.8;                               	% emissivity of surface (-)
T_ini=293.15;                       	% initial temperature (K)
T_f=743.15;                         	% final oven temperature (K)
t_hold=1000;                        	% oven hold temperature (s)
beta=1;                             	% oven ramp rate (K/s)
c=500;                              	% specific heat capacity (J/kg-K)
k=50;                               	% conductivity (W/m-K)
rho=8700;                           	% density  (kg/m^3)
sigma=5.67e-8;                       	% Stefan-Boltzmann constant (W/m^2-K^4)

sigma=5.67e-8;                      %Stefan-Boltzmann constant (W/m^2-K^4)
h_rad_max=sigma*e*(T_f^2+T_f^2)*(T_f+T_f);	%maximum radiation coefficient
L_c=V/A_s;                          %characteristic length for conduction (m)
Bi=h_rad_max*L_c/k                  %maximum Biot number
										
tau=rho*c*V/(h_rad_max*A_s)         %time constant

DELTAt=t_sim/(M-1);                 	% time step duration
for j=1:M
    time(j)=(j-1)*t_sim/(M-1);    	% value of time for each step
    T_w(j)=T_wf(time(j),T_ini,T_f,beta,t_hold);       % value of the wall temperature at each step
end

%Heun's Method
T(1)=T_ini;
for j=1:(M-1)
   dTdt=e*A_s*sigma*(T_w(j)^4-T(j)^4)/(rho*V*c); 	%Temp deriv. at the start of the time step
   T_hat=T(j)+dTdt*DELTAt;                              	%Predictor step
   dTdt_hat=e*A_s*sigma*(T_w(j+1)^4-T_hat^4)/(rho*V*c); 	%deriv. at end of time step
   T(j+1)=T(j)+(dTdt+dTdt_hat)*DELTAt/2;                	%Corrector step"
end

%Solution determined by ode solver
[time, T_m]=ode45(@(time,T)  dTdt_f(time,T,e,A_s,rho,V,c,T_f,T_ini,beta,t_hold),time,T_ini);

end

function[T_w]=T_wf(time, T_ini, T_f, beta, t_hold)
% Oven temperature function
% Inputs
% time - current time value (s)
% T_ini - initial value of the wall (K)
% T_f - final value of the wall (K)
% beta - rate of increase in temperature of the wall (K/s)
% t_hold - time period in which the wall temperature is held constant (s)
            
% Output
% T_w - wall temperature at specfied time (K)
 
    T_w=T_ini+beta*time;
    t_ramp=(T_f-T_ini)/beta;
    if (time>t_ramp) 
        T_w=T_f;
    end
    if (time>(t_ramp+t_hold)) 
        T_w=T_f-beta*(time-t_ramp-t_hold);
    end
    if (time>(2*t_ramp+t_hold))
        T_w=T_ini;
    end
end

function[dTdt]=dTdt_f(time,T,e,A_s,rho,V,c,T_f,T_ini,beta,t_hold)
%Function dTdt_f is called by the MATLAB ode45 solver to evaluate the derivative dTdt 
   sigma=5.67e-8;   	% Stefan-Boltzmann constant (W/m^2-K^4)
   T_w=T_wf(time, T_ini, T_f, beta, t_hold);
   dTdt=e*A_s*sigma*(T_w^4-T^4)/(rho*V*c); %Temp deriv.;
end
 
